*_____________________________________________________________________________________________________________________________________________________
*
* GLOBALS AND FILE LOCATIONS
*_____________________________________________________________________________________________________________________________________________________

version 14							// No longer have to set mem in Stata v12
clear
estimates clear
clear matrix 
clear mata
macro drop _all						// Must do this BEFORE setting the dir globals below!
pause on
set maxvar 20000
set more off
* To install: SSC INSTALL (gllamm | estout | estwrite) net install dm79, from(http://www.stata.com/stb/stb56) =SVMAT2 | net install spost9_ado, from(http://www.indiana.edu/~jslsoc/stata) =MISSCHK | dm88_1.pkg (RENVARS) | estwrite, from(http://fmwww.bc.edu/RePEc/bocode/e)
global dodir 	"C:\Users\bpb\Dropbox\Disability work\ESRC Future Leaders Disability\Phase 1 (Dis Emp Rates) - Intl\ELSA-SHARE-HRS"
global sharedir	"C:\Users\bpb\Desktop\Datasets Misc\Global Aging Data - SHARE\Release 6"
global shareversno	"rel6-0-0"		// The version number of the SHARE release - which affects the filenames
	/* The previous version of SHARE, which the RAND files were designed for when this was started (removed Nov 2017)
	global v5sharedir		"C:\Users\bpb\Desktop\Datasets Misc\Global Aging Data - SHARE\Release 5"
	global v5shareversno	"rel5-0-0"		
	*/
global elsadir 	"C:\Users\bpb\Desktop\Datasets Misc\Global Aging Data - ELSA (SN5050)"
	global elsadatadir	"${elsadir}\stata\stata13_se"
	global elsaw1	"${elsadatadir}\wave_1_core_data_v3_lower.dta"
	global elsaw2	"${elsadatadir}\wave_2_core_data_v4_lower.dta"
	global elsaw3	"${elsadatadir}\wave_3_elsa_data_v4_lower.dta"
	global elsaw4	"${elsadatadir}\wave_4_elsa_data_v3_lower.dta"
	global elsaw5	"${elsadatadir}\wave_5_elsa_data_v4_lower.dta"
	global elsaw6	"${elsadatadir}\wave_6_elsa_data_v2_lower.dta"
	global elsaw7	"${elsadatadir}\wave_7_elsa_data_lower.dta"
	global elsaw2_nurse	`"${elsadatadir}\wave_2_nurse_data_v2_lower.dta"'
	global elsaw4_nurse	`"${elsadatadir}\wave_4_nurse_data_lower.dta"'
	global elsaw6_nurse	`"${elsadatadir}\wave_6_elsa_nurse_data_v2_lower.dta"'
global hrsdir	"C:\Users\bpb\Desktop\Datasets Misc\Global Aging Data - HRS"		
	*global hrsbiomarkers	"${hrsdir}\biomarkers\biomarkers.dta"							// These have some preprep done - add the biomarkers.do file to the public code
	global hrsincome		"${hrsdir}\RAND income & wealth imputations\incwlth_p.dta"
	global hrsfatfiles		"${hrsdir}\RAND fat files"
global countryleveldir	"C:\Users\bpb\Dropbox\Disability work\ESRC Future Leaders Disability\Phase 1 (Dis Emp Rates) - Intl"		// For merging into stage 2 models
global refstatsdir 		"C:\Users\bpb\Dropbox\WS\x. Ref WS stats"																	// For the OECD policy scores in full

// Follow-on dirs
global logdir		"${dodir}\z. Logs and ref"
	capture log close
	local cday = day(date("`c(current_date)'", "DMY"))
	local cmth = month(date("`c(current_date)'", "DMY"))
	local cyr  = year(date("`c(current_date)'", "DMY"))
	log using "${logdir}\Log `cyr'-`cmth'-`cday'.txt", text append
global versno 	"v3_6"							
	notes _dta: v1 is 2015 version for NNDR conference paper
	notes _dta: v2 is 2017 version for ESPAnet
	notes _dta: v3 is for Boheim-Leoni collaboration 2017-18
	notes _dta: v3-4 is Jan 2018 version for B-L
	notes _dta: v3-5 updates the disability benefit vars
	notes _dta: v3-6 is for multiple imputation and moves data cleaning out of analysis files
exit


*_____________________________________________________________________________________________________________________________________________________
*
* PRELIMINARIES - to be done once
*_____________________________________________________________________________________________________________________________________________________

*Preparation - only needs running once
	// MAKING ALL DATASETS LOWERCASE - for ELSA, this is in new files as otherwise the SHARE syntax doesn't work
	forvalues i = 1/7 {
		local origfile = subinstr("${elsaw`i'}", "_lower.dta", ".dta", .)
		use "`origfile'", replace
		renvars, lower
		save "${elsaw`i'}", replace
	/**/ }
	foreach i in 2 4 6 {
		local origfile = subinstr("${elsaw`i'_nurse}", "_lower.dta", ".dta", .)
		use "`origfile'", replace
		renvars, lower
		save "${elsaw`i'_nurse}", replace
	/**/ }
	use "${hrsdir}\RAND fat files\hd10f5c.dta"
	renvars, lower
	save, replace
	
	// RUNNING RAND FILES, WHICH I THEN ADD FURTHER VARIABLES TO IN THE CLEANING .DO FILES BELOW
	capture noisily which distinct
		if rc~=0		ssc install distinct		// BBG MOVED FROM SHARE HARMONISATION (used for counting distinct observations)
	do "${dodir}\Data cleaning\1_harmonised_ELSA_master.do"
	do "${dodir}\Data cleaning\1_H_SHARE_long_vD.do"					// Until 21/7/2017 this was v5 of SHARE, from 1_harmonised_SHARE_master.do | Then was Mariska version | Finally from 13/11/2017, was RAND file version D
	do "${dodir}\Data cleaning\2_H_SHARE_v5_master.do"					// SHARE v5 - this is neceessary for some variables that BBG/MvdH were unable to make work with the revised imputations



*_____________________________________________________________________________________________________________________________________________________
*
* CLEANING - to be done each time the dataset is changed
*_____________________________________________________________________________________________________________________________________________________


// Individual files
do "${dodir}\1_cleaning_HRS.do"
do "${dodir}\1_cleaning_SHARE.do"
do "${dodir}\1_cleaning_ELSA.do"

// Merging
use "${hrsdir}\HRS_BBG_${versno}.dta", replace
append using "${elsadir}\ELSA_BB_${versno}.dta"
append using "${sharedir}\SHARE_BB_${versno}.dta"
do "${dodir}\2_cleaningXsurvey_labelling.do"
save "${hrsdir}\HRS-SHARE-ELSA_BBG_${versno}.dta", replace
do "${dodir}\2_ret_age.do"
save "${hrsdir}\HRS-SHARE-ELSA_BBG_${versno}.dta", replace


// My own dataset
use "${hrsdir}\HRS-SHARE-ELSA_BBG_${versno}.dta", replace
keep if (ragey>=50 & ragey<60)
svyset [pweight=rwtresp2], strata(survey_waveN)
save "${hrsdir}\HRS-SHARE-ELSA_BBG_${versno}.dta", replace



*_____________________________________________________________________________________________________________________________________________________
*
* BOHEIM-LEONI PROJECT 2017-18
*_____________________________________________________________________________________________________________________________________________________

do "${dodir}\Boheim-Leoni reference files\10_boheimleoni_part0 (master).do"


	