

/*

	CREATE LATENT HEALTH INDICATORS

*/

*****************************************************************************************************************
** THIS VERSION: 7 May 2018  ** SENSITIVITY VERSION, LATENT HEALTH INDICATOR RESTRICTED TO POPULATION 54 TO 65 **
*****************************************************************************************************************

*global {hrsdir} 	"I:\fachref\leoni\ESPAnet2017\data"
*global {hrsdir} 	"I:\fachref\leoni\ESPAnet2017\data"


******************************************************************************
** Merge with SHARE data to calculate pooled hlth indic over all countries **
******************************************************************************

use "${hrsdir}\BoheimLeoniGeiger_v3_6.dta", clear

cap drop sphus45
gen sphus45=.
replace sphus45=0 if rshlt<4
replace sphus45=1 if rshlt==4 | rshlt==5

cap rename ragey age

replace ret_age=65 if country==25  // fill-in default retirement age for Israel, because otherwise completely missing

gen underw = 0 if !missing(rbmicat)
replace underw = 1 if rbmicat==1

gen obese  = 0 if !missing(rbmicat)
replace obese = 1 if rbmicat==4

/* 
  Variable list for health indicators
  MISSINGS and corrections  
*/  
  
foreach var in rwalk100a rlifta rpusha anyADL rclim1a rclimsa rstoopa rdimea rsita rchaira rarmsa rback rhibpe rstroke rdiabe rlunge rhearte rcancre rarthre rmhcase rmhscale_Z sphus45 rhosp rhomcar rdoctim rnrshom rbmicat   {
				mdesc `var'
				}    // High number of missings: rback, rhosp, rhomcar rdoctim rnrshom, moderate number of missing: rbmicat

/* 
  Adapt sample  
*/ 				
				
/*
Retain only the following countries: 51 USA, 61 England plus 
11 Austria, 
12 Germany, 
13 Sweden, 
14 Netherlands (4 waves), 
15 Spain, 
16 Italy, 
17 France, 
18 Denmark, 
19 Greece (3 waves), 
20 Switzerland, 
23 Belgium, 
25 Israel (4 waves), 
28 Czech Republic (4 waves),
29 Poland (3 waves),
34 Slovenia (3 waves),
35 Estonia (3 waves). 
*/

egen OK = anymatch(country), values(11 12 13 14 15 16 17 18 19 20 23 25 28 29 51 61)
keep if OK

drop if country==61 & wave==3         // drop ELSA W3 (because of SRH)

drop country_waveN
egen country_waveN = group(country wave), label   // replace existing country_waveN to have a continuous numerical country-wave identifier
tab country_waveN, nolab
tab country_waveN
sum country_waveN
local g = r(max)

drop country2
egen country2 = group(country), label   // replace existing country_waveN to have a continuous numerical country-wave identifier
tab country2, nolab
tab country2


/*
Match wave and generate a new wave indicator
*/

gen wave_tmp = wave      // gen new wave variable
replace wave_tmp=1 if wave==7 & survey=="HRS"
replace wave_tmp=2 if wave==8 & survey=="HRS"
replace wave_tmp=3 if wave==9 & survey=="HRS"
replace wave_tmp=4 if wave==10 & survey=="HRS"
replace wave_tmp=5 if wave==11 & survey=="HRS"
replace wave_tmp=6 if wave==12 & survey=="HRS"


**************
***  PCA  ****
**************

/*
***pca_varlist is constant for all waves (and across all country in the preferred version)
*/

*New ESPAnet2017 version: includes rclimsa (ph048d4); no health care variables (for ELSA problems); no rback (problems); both anyADL and anyIADL; rmhscale_Z?

global pca_varlist rwalk100a rlifta rpusha anyADL anyIADL rclim1a rclimsa rstoopa rdimea rsita rchaira rarmsa rhibpe rstroke rdiabe rlunge rhearte rcancre rarthre rmhcase rmhscale_Z sphus45 underw obese
global pca_varlist_sens rwalk100a rlifta rpusha anyADL anyIADL rclim1a rclimsa rstoopa rdimea rsita rchaira rarmsa rhibpe rstroke rdiabe rlunge rhearte rcancre rarthre rmhcase rmhscale_Z sphus45 underw obese rhosp rhomcar rdoctim rnrshom 


/*
Separately for each country, pooling all waves
*/

gen pca_cntr=.
label var pca_cntr "latent health index by PVW (2013), countries separately"

foreach ctry in 11 12 13 14 15 16 17 18 19 20 23 25 28 29 51 {
		    local value_label : label (country) `ctry'
			display""
			display""
			display""
			display""
			display in smcl as text "These are the results for `ctry' -> " as result "`value_label'"

		pca $pca_varlist if age>=54 & age<=67 & country==`ctry', components(3)
		estat loadings 
		predict pc1, score
		replace pca_cntr=pc1 if !missing(pc1) & age>=54 & age<=67 & country==`ctry'
		drop pc1
}


	noi display "These are the results for England"

		pca $pca_varlist if age>=54 & age<=67 & country==61, components(3)
		estat loadings 
		predict pc1, score
		replace pca_cntr=pc1 if !missing(pc1) & age>=54 & age<=67 & country==61
		drop pc1


sum pca_cntr, d	                  // to scale index between 1 and 0
replace pca_cntr=1-(pca_cntr-r(min))/(r(max) - r(min))

bys survey_waveN: mdesc pca_cntr if age<=ret_age


/*
Calculate percentiles (ATTENTION: percentiles within country, wave and population within statutory retirement age)
*/

gen c_pvw100=.

label var c_pvw100 "percentile PVW index, countries & wave separately"

forvalues ctryw = 1/`g' {
				xtile c_pvw100_`ctryw' = pca_cntr if country_waveN==`ctryw' & age>=54 & age<=65, nq(100)
				replace c_pvw100=c_pvw100_`ctryw' if country_waveN==`ctryw'
				drop c_pvw100_`ctryw'
			}


/*
SAVE the health indicators  
*/

preserve	
keep mergeid country wave survey pca_cntr c_pvw100 age ret_age sphus45
save "${hrsdir}\v3_6_boheimleoniPCA_5467.dta", replace
restore


************************************************************
************************************************************

/*
Check missings 
*/

*log using "I:\fachref\leoni\ESPAnet2017\logfiles\missing_pvw100_apr2018.smcl", replace

foreach var in pca_cntr c_pvw100 {
	display""
	display""
	display "These are the missings for  " `"`: var label `var' '"'
	bys country: mdesc `var' if age>=54 & age<=65
}


foreach var in $pca_varlist  {
	display""
	display""
	bys country_waveN: mdesc `var' if age>=54 & age<=65  
}

log close

/*
check again missings
*/

bys country_waveN: mdesc c_pvw100 if age>=54 & age<=65   
bys country_waveN: mdesc pca_cntr if age>=54 & age<=65
