/*
	
	Generate analytical sample (BBL 2017)
	
	Descriptive analysis and graphs
	
*/
set more off

*global inputDir 	"I:\fachref\leoni\ESPAnet2017\graphs\new9may"
global graphtmpDir 	"I:\fachref\leoni\ESPAnet2017\graphs\temp"
global tempDir 		"I:\fachref\leoni\SHARE\temp"
*global {hrsdir} 	"I:\fachref\leoni\ESPAnet2017\data"
*global {hrsdir} 	"I:\fachref\leoni\ESPAnet2017\data"
global outputTab 	"I:\fachref\leoni\ESPAnet2017\tables"

*******************************
** THIS VERSION: 10 May 2018 **
*******************************

*_____________________________________________________________________________________________________________________________________________________
*
* Step 1: Include pooled health indicators
*_____________________________________________________________________________________________________________________________________________________

use "${hrsdir}\BoheimLeoniGeiger_v3_6.dta", clear

/* 
  Adapt sample  
*/ 				
				
/*
Retain only the following countries: 51 USA, 61 England plus 
11 Austria, 
12 Germany, 
13 Sweden, 
14 Netherlands (4 waves), 
15 Spain, 
16 Italy, 
17 France, 
18 Denmark, 
19 Greece (3 waves), 
20 Switzerland, 
23 Belgium, 
25 Israel (4 waves), 
28 Czech Republic (4 waves),
29 Poland (3 waves),
34 Slovenia (3 waves),
35 Estonia (3 waves). 
*/

egen OK = anymatch(country), values(11 12 13 14 15 16 17 18 19 20 23 25 28 29 34 35 51 61)
keep if OK
drop OK

drop if country==61 & wave==3         // drop ELSA W3 (because of SRH)

drop country_waveN
egen country_waveN = group(country wave), label   // replace existing country_waveN to have a continuous numerical country-wave identifier
tab country_waveN, nolab
tab country_waveN
sum country_waveN
local g = r(max)


drop country2
egen country2 = group(country), label   // replace existing country_waveN to have a continuous numerical country-wave identifier
tab country2, nolab
tab country2


/*
Here we add health indicators (pca) as well as information on statutory retirement age. See do-file bbl_2017_health_indic_HRSnSHAREnELSA
*/

merge 1:1 mergeid wave using "${hrsdir}\v3_6_boheimleoniPCA.dta", generate(merge_hindic) keep(match master)


/*

/* Test for exclusion of BMI in latent health indicator*/
drop pca_cntr c_pvw100
rename pca_cntr_nbmi pca_cntr
rename c_pvw100_nbmi c_pvw100

*global inputDir 	"I:\fachref\leoni\ESPAnet2017\graphs\nbmi"
*/

*_____________________________________________________________________________________________________________________________________________________
*
* Step 2: Some additional data preparation
*_____________________________________________________________________________________________________________________________________________________

carryforward rmale if missing(rmale) & country==51 & wave==6, replace  // 6 observations with missing gender information in HRS Wave 6

*gen age = ragey 
gen age_sq = age*age

gen injob = rworknew  // 1: person is currently employed. 

gen retired=0                          //  person is currently retired
replace retired=1 if rlbrf_s==5 | rlbrf_e==5 | rlbrf==5
replace retired=. if missing(rlbrf_s) & missing(rlbrf_e) & missing(rlbrf)

gen unemp=0                          //  person is currently unemployed
replace unemp=1 if rlbrf_s==3 | rlbrf_e==3 | rlbrf==3
replace unemp=. if missing(rlbrf_s) & missing(rlbrf_e) & missing(rlbrf)

gen home=0                        //  person is currently homemaker
replace home=1 if rlbrf_s==8 | rlbrf_e==7 | rlbrf==7
replace home=. if missing(rlbrf_s) & missing(rlbrf_e) & missing(rlbrf)

gen disab=0                         //  labour force status is permanently sick or disabled (very imperfect overlap with receipt of disability benefits)
replace disab=1 if rlbrf_s==6 | rlbrf_e==6 | rlbrf==6
replace disab=. if missing(rlbrf_s) & missing(rlbrf_e) & missing(rlbrf)

gen empl=0                          //  alternative definition of employment
replace empl=1 if rlbrf_s==1 | rlbrf_e==1 | rlbrf_e==2 | rlbrf_e==4 | rlbrf==1 | rlbrf==2 | rlbrf==4
replace empl=. if missing(rlbrf_s) & missing(rlbrf_e) & missing(rlbrf)

gen lbrf_new=.
replace lbrf_new=1 if empl==1
replace lbrf_new=2 if unemp==1
replace lbrf_new=3 if retired==1
replace lbrf_new=4 if disab==1
replace lbrf_new=5 if home==1

replace lbrf_new=1 if rworknew==1   // ATTENTION: New Version (Feb 12, 2018), to account for superiority of rworknew over rlbrf

label define lbrfnew 1 "employed" 2 "unemployed" 3 "retired" 4 "disab" 5 "home"
label values lbrf_new lbrfnew


foreach var in c_pvw100  {   // generate variables with quantile categories of health indicator
		gen `var'_3 = 0 
		replace `var'_3 = 1 if `var' <34 & !missing(`var')

		gen `var'_4 = 0 
		replace `var'_4 = 1 if `var' <26 & !missing(`var')
}		


gen pensionage=0                  // indicators for (normal, statutory) retirement age and age 50 to 60
	replace pensionage=1 if age > ret_age
	replace pensionage=. if age < 50

gen natage=0
	replace natage=1 if age <= 60
	replace natage=. if age < 50

	
/*
declare as times series data and create variables
*/

gen wave_orig=wave
drop wave

gen wave = wave      // gen new wave variable
replace wave=wave_orig-6 if survey=="HRS"

egen newmergeid = group(mergeid)

xtset newmergeid wave

xtdes 

gen lfsw1=f.lbrf_new  // LFS status in next wave
gen lfsw2=f2.lbrf_new   // LFS status two waves later
gen lfsw3=f3.lbrf_new   // LFS status three waves later

tab lbrf_new lfsw1, row col nof m

gen w1injob=f.injob   // Employed in next wave
gen w2injob=f2.injob   // Employed  two waves later
gen w3injob=f3.injob   // Employed three waves later

gen injob_1=l.injob   // Employed  in previous wave
gen injob_2=l2.injob   // Employed  two waves earlier

gen w1unemp=f.unemp   // LFS status in next wave
gen w2unemp=f2.unemp   // LFS status two waves later

gen w1retired=f.retired   // retired in next wave
gen w2retired=f2.retired   // retired two waves later

gen w1age=f.age   // retired in next wave
gen w2age=f2.age   // retired two waves later


gen w1_pvw100=f.c_pvw100     // change in health status
gen w2_pvw100=f2.c_pvw100

table c_pvw100 w1_pvw100, row col m

gen w1pensionage=f.pensionage // pensionage in next wave
gen w2pensionage=f2.pensionage   // pensionage two waves later

gen lfsw_1=l.lbrf_new if wave  // LFS status in previous wave
gen lfsw_2=l2.lbrf_new   // LFS status two waves earlier
gen lfsw_3=l3.lbrf_new   // LFS status three waves earlier

gen riwy_1=l.riwy  // interview year previous wave
gen riwy_2=l2.riwy  // interview year two waves earlier

recode c_pvw100 (1/33=1)(34/66=2)(.=.)(else=3), gen(Htert)
gen Htert_1=l.Htert  // health tertile in previous wave


/* 
some labels
*/

label define dcountries ///   // new country labels
    11 "Austria" ///
    12 "Germany" ///
    13 "Sweden" ///
    14 "Netherlands" ///
    15 "Spain" ///
    16 "Italy" ///
    17 "France" ///
    18 "Denmark" ///
    19 "Greece" ///
    20 "Switzerland" ///
    23 "Belgium" ///
    25 "Israel" ///
    28 "Czech Republic" ///
    29 "Poland" ///
    30 "Ireland" ///
    31 "Luxembourg" ///
    32 "Hungary" ///
    33 "Portugal" ///
    34 "Slovenia" ///
    35 "Estonia" ///
	51 "USA" ///
	61 "England", replace

label values country dcountries	

label variable c_pvw100_3 "pca tertile by country/wave"
label variable c_pvw100_4 "pca quartile by country/wave"

label variable lbrf_new "labour market status of R"

label variable lfsw1 "labour market status in following wave"
label values lfsw1 lbrfnew
	label variable lfsw2 "LFS status two waves later"
	label values lfsw2 lbrfnew
		label variable lfsw3 "LFS status three waves later"
		label values lfsw3 lbrfnew

label variable lfsw_1 "labour market status in previous wave"
label values lfsw_1 lbrfnew
	label variable lfsw_2 "LFS status two waves earlier"
	label values lfsw_2 lbrfnew
		label variable lfsw_3 "LFS status three waves earlier"
		label values lfsw_3 lbrfnew		
		
label variable riwy_1 "interview year previous wave"
label variable riwy_2 "interview year two waves earlier"

label define noyes 0 "no"  1 "yes"
label values rwld noyes

label variable w1injob "Employed next wave"
label values w1injob noyes
	label variable w2injob "Employed two waves later"
	label values w2injob noyes
		label variable w3injob "Employed three waves later"
		label values w3injob noyes

label variable injob_1 "Employed previous wave"
label values injob_1 noyes
	label variable injob_2 "Employed two waves earlier"
	label values injob_2 noyes

label variable Htert "Tertile of health distribution"
label variable Htert_1 "Tertile of health distribution in previous wave"


// New Country labelling
numlabel countrynew, mask(#_) remove
capture drop working
decode country, gen(working)
* In order of the employment gap
	capture drop country_ord 
	capture label drop country_ord
label define country_ord 1 "Austria" , modify
label define country_ord 2 "USA" , modify
label define country_ord 3 "France" , modify
label define country_ord 4 "Italy" , modify
label define country_ord 5 "Belgium" , modify
label define country_ord 6 "Germany" , modify
label define country_ord 7 "England" , modify
label define country_ord 8 "Greece" , modify
label define country_ord 9 "Denmark" , modify
label define country_ord 10 "Spain" , modify
label define country_ord 11 "Netherlands" , modify
label define country_ord 12 "Switzerland" , modify
label define country_ord 13 "Sweden" , modify
encode working, gen(country_ord) label(country_ord)
	label var country_ord "Country (ordered for graphing, no numeric codes)"
* In alphabetic order with US and England at the top
	capture drop country_alph 
	capture label drop country_alph
label define country_alph 1 "USA", modify
label define country_alph 2 "England", modify
label define country_alph 3 "Austria", modify
label define country_alph 4 "Belgium", modify
label define country_alph 5 "Denmark", modify
label define country_alph 6 "France", modify
label define country_alph 7 "Germany", modify
label define country_alph 8 "Greece", modify
label define country_alph 9 "Italy", modify
label define country_alph 10 "Netherlands", modify
label define country_alph 11 "Spain", modify
label define country_alph 12 "Sweden", modify
label define country_alph 13 "Switzerland", modify
encode working, gen(country_alph) label(country_alph)
	label var country_alph "Country (alphabetic for graphing, no numeric codes)"
* Final tidying
numlabel countrynew, mask(#_) add
tab1 country country_ord country_alph


/*
Generate decile scores based on the PCA health indicator
*/

gen c_pvw10=.

label var c_pvw10 "decile PCA index, countries and waves separately"

forvalues ctryw = 1/`g' {
				xtile c_pvw10_`ctryw' = pca_cntr if country_waveN==`ctryw' & age<=ret_age, nq(10)
				replace c_pvw10=c_pvw10_`ctryw' if country_waveN==`ctryw'
				drop c_pvw10_`ctryw'
			}


/*
Generate information on tenure and mobility, to be used for recruitment vs. retention
*/			
			
gen short_ten = rjcten - (riwy - riwy_1) if injob==1   // Identify persons with job change since last interview

gen mobile = . if injob==0 | missing(injob)
replace mobile = 0 if short_ten > 0
replace mobile = 1 if short_ten <= 0

label variable mobile "New job since last wave"
  
gen cont_emp = .  // Continuous employment, from last wave
replace cont_emp = 0 if injob==1 & injob_1==1 & mobile==0  // Currently and previously employed, no job change
replace cont_emp = 1 if injob==1 & injob_1==1 & mobile==1  // Currently and previously employed, job change
replace cont_emp = 2 if injob==1 & injob_1==0              // Currently employed, previously not employed

label define contin 0 "Same job"  1 "Job change" 2 "Previously not employed"
label values cont_emp contin

label variable cont_emp "Employment continuity from last wave"

**

xtset newmergeid wave

gen cont_emp_1 = f.cont_emp

gen w1cont_emp = .  // Continuous employment, to next wave
replace w1cont_emp = 0 if cont_emp_1==0       // Employed now and in next W, no change
replace w1cont_emp = 1 if cont_emp_1==1		  // Employed now and in next W, job change
replace w1cont_emp = 2 if injob==1 & w1injob==0   // Employed now but not in next W
replace w1cont_emp = 3 if injob==0 & w1injob==1   // Employed in next W, but not now 
replace w1cont_emp = 4 if injob==0 & w1injob==0   // Never employedEmployed in next W

label define contn 0 "Same job"  1 "Job change" 2 "Not employed in next wave" 3 "Not employed now, employed in next wave" 4 "Not employed now and in next wave"
label values w1cont_emp contn

label variable w1cont_emp "Employment continuity to next wave"
			

*_____________________________________________________________________________________________________________________________________________________
*
* Step 3: Relationship between health and employment, accounting for gender/age structure
*_____________________________________________________________________________________________________________________________________________________

global health "c_pvw100"
global weight "rwtresp2"
global age_limit "age>=50 & age<=ret_age"

/*
  Establish relationship between health and employment likelihood, after controlling for gender and age 
  Use 4th order polynomial
*/

gen h2 = $health * $health
gen h3 = $health * $health * $health 
gen h4 = $health * $health * $health * $health


** W I T H O U T covariates

gen injobht=.

forvalues ctryw = 1/`g' {
					    local value_label: label (country_waveN) `ctryw'
						display""
						display""
						display""
						display""
						display in smcl as text "These are the results for `ctryw' -> " as result "`value_label'"
				reg injob $health h2 h3 h4 if country_waveN==`ctryw' & $age_limit
				replace injobht=_b[$health] * $health +_b[h2]*h2+_b[h3]*h3+_b[h4]*h4 if country_waveN==`ctryw' & e(sample)==1
}


** W I T H covariates

gen injobpr_c=.

forvalues ctryw = 1/`g' {
					    local value_label : label (country_waveN) `ctryw'
						display""
						display""
						display""
						display""
						display in smcl as text "These are the results for `ctryw' -> " as result "`value_label'"
				reg injob $health h2 h3 h4 age age_sq rmale if country_waveN==`ctryw' & $age_limit
				predict yhatt
				replace injobpr_c =  yhatt if country_waveN==`ctryw' & e(sample)==1
				drop yhatt
}


save "${hrsdir}\bbl_2017_analysis.dta", replace				


*_____________________________________________________________________________________________________________________________________________________
*
* Step 4: Analysis and graphs
*_____________________________________________________________________________________________________________________________________________________

use "${hrsdir}\bbl_2017_analysis.dta", clear

* Country inclusion
label define countrynew 28 "28_CzechRepublic", modify	  	// to avoid problems with estimates storing (Czech Republic with space interpreted as two names)
drop if inlist(country, 25, 34, 35, 28, 29)  // to get rid of Israel, Slovenia, Estonia, Czech R, Poland (insufficient sample size/waves to get anything other than very wide confidence intervals)


global health "c_pvw100"
global weight "rwtresp2"
global age_limit "age>=50 & age<=ret_age"


replace wave=wave_orig-1 if survey=="ELSA" 		//	Previously only done for wave>=4
	*recode wave (3=2) if survey=="ELSA"
	label var wave "NEW VERSION OF WAVE (HRS=wave-6, ELSA=wave-1)"		// BBG added

recode wave (1/2=1 "w1-2")(5/6=2 "w5-6")(else=.), gen(trend)
	label var trend "Dummy for waves 1-2 vs. 5-6"
	
	
************************************************************************************************************************
*** PART 1: DIS EMP GAP, replicating Boheim-Leoni analysis but with new graph syntaxStart analyses and descriptives  ***
************************************************************************************************************************

// Country selection: remove numbers from country labels & make consecutive to make nicer graphs
numlabel countrynew, mask(#_) remove						
	capture drop country2
	egen country2 = group(country), label   				// replace existing country2 to have a continuous numerical country-wave identifier
	order country2, after(country)
	label var country2 "Country in consecutive numerical order (at the time created)"
	numlabel countrynew, mask(#_) add


	// Models with overall gender/age adjustment
reg injob i.Htert##i.country2##i.trend age age_sq rmale if $age_limit [pw=${weight}], cluster(mergeid)
gen mainsample=1 if e(sample)==1
estimates store regbase
	margins r3.Htert#r.trend@i.country2, post	
	pause
		marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) title("") xtitle("Change in health emp. gap over time") ytitle("") xscale(r(-.3 .3)) xlabel(-0.30(0.1)0.30,format(%3.2f))
*	graph export "${boheimleoni_graphs}\0.BBG_gaptrendbycountry.png", width(800) height(600) as(png) replace
	estimates restore regbase
	margins r.trend@i.country2, at(Htert==1) post	
		marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) title("") xtitle("Change in emp among poorest health over time") ytitle("") xscale(r(-.3 .3)) xlabel(-0.30(0.1)0.30,format(%3.2f))
*		graph export "${boheimleoni_graphs}\0.BBG_leveltrendbycountry.png", width(800) height(600) as(png) replace


	// Models with country-specific gender/age-adjustment

	reg injob i.Htert##i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit  [pw=${weight}], cluster(mergeid)
estimates store regbase	
* MARGINS
margins r3.Htert#r.trend@i.country_alph if e(sample), post	
  * MARGINSPLOT
  marginsplot, horizontal /*unique*/ xline(0) recast(scatter) yscale(reverse) title("") xtitle("Change in health emp. gap over time") ytitle("") xscale(r(-.3 .3)) xlabel(-0.30(0.1)0.30,format(%3.2f))
  graph export "${boheimleoni_graphs}\0.BBG_gaptrendbycountry.png", width(800) height(600) as(png) replace
	* This is the additional plot (done by accident, BBG)
	estimates restore regbase
	margins r3.Htert@i.country_alph#i.trend if e(sample), contrast
	marginsplot, horizontal unique recast(scatter) yscale(reverse) title("") xtitle("Health employment gap, comparison over time") ytitle("") legend(order (3 "2004/7" 4 "2012/15")) xlabel(,format(%3.2f))
	graph export "${boheimleoni_graphs}\0.BBG_gaplevel.png", width(800) height(600) as(png) replace
		* MARGINS
		estimates restore regbase
		margins r.trend@i.country_alph, at(Htert==1) post
			* MARGINSPLOT
			marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) title("") xtitle("Change in emp among poorest health over time", margin(medium)) ytitle("") xscale(r(-.3 .3)) xlabel(-0.30(0.1)0.30,format(%3.2f))
			graph export "${boheimleoni_graphs}\0.BBG_leveltrendbycountry.png", width(800) height(600) as(png) replace

graph close _all
		
*drop trend		


************************************************************
*** PART 2: FURTHER STUDY OF A SMALLER SET OF COUNTRIES  ***
************************************************************

egen OK = anymatch(country), values(11 12 13 16 18 20 51 61)
keep if OK
drop OK

// Adjust Country labelling
numlabel countrynew, mask(#_) remove
capture drop working
decode country, gen(working)
* In alphabetic order with US and England at the top
	capture drop country_alph 
	capture label drop country_alph
label define country_alph 1 "USA", modify
label define country_alph 2 "England", modify
label define country_alph 3 "Austria", modify
label define country_alph 4 "Denmark", modify
label define country_alph 5 "Germany", modify
label define country_alph 6 "Italy", modify
label define country_alph 7 "Sweden", modify
label define country_alph 8 "Switzerland", modify
encode working, gen(country_alph) label(country_alph)
	label var country_alph "Country (alphabetic for graphing, no numeric codes)"
* Final tidying
numlabel countrynew, mask(#_) add
tab1 country_alph


// This version of disability benefits
global disben		"rbeninc2_dis"
if "${disben}"=="rbeninc3_dis"		recode rbeninc3_dis (2=1)			// Ignoring whether imputed or not
gen benvwork = ${disben}
	replace benvwork = 2 if rworknew==1 & ${disben}==1
	label define benvwork 0 "not claiming" 1 "claiming not working" 2 "claiming + working", replace
	label values benvwork benvwork
	label var benvwork "Combined dis ben claim + work status"
	tab benvwork, gen(benvwork)


//////////////////////////////////////////
// 1. DIS BEN RECEIPT LEVELS
// Differences by health status
//////////////////////////////////////////

eststo disben_base: logit ${disben} i.country_alph c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
margins i.country_alph, post	
	marginsplot, horizontal unique xline(0) recast(scatter)  xlabel(, format(%3.2f))  ///
		title("") xtitle("Bottom health tertile") ytitle("") yscale(reverse)		///
		note("") name(di_level_1tert, replace)
	
	
eststo disben_base: logit ${disben} i.country_alph c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert!=1 [pw=${weight}], cluster(mergeid)
margins i.country_alph, post	
	marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) yscale(off) xlabel(, format(%3.2f))  ///
		title("") xtitle("Upper health tertiles") ytitle("")		///
		note("") name(di_level_2_3tert, replace)
	
		graph combine di_level_1tert di_level_2_3tert, xcommon xsize(8) title("Disability benefit receipt (all waves)", margin(medium))	
	graph export "${boheimleoni_graphs}\1.0 BBG_disben_levelbycountry.png", width(800) height(600) as(png) replace	

	
//////////////////////////////////////////
// 1. DIS BEN RECEIPT OVER TIME
// Trend by country
//////////////////////////////////////////

eststo disben_base: logit ${disben} i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit [pw=${weight}], cluster(mergeid)
margins r.trend@i.country_alph, post	
	marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) xlabel(, format(%3.2f))  ///
		title("") xtitle("Change in disability benefit receipt") ytitle("")		///
		note("")
	graph export "${boheimleoni_graphs}\1.a BBG_disben_trendbycountry.png", width(800) height(600) as(png) replace

eststo disben_base: logit ${disben} i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
margins r.trend@i.country_alph, post	
	marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) xlabel(, format(%3.2f))  ///
		title("") xtitle("Change in DI benefit receipt - Bottom health tertile") ytitle("")		///
		note("") name(disben_1tert, replace)
	graph export "${boheimleoni_graphs}\1.b BBG_disben_trendbycountry.png", width(800) height(600) as(png) replace	
	
	
eststo disben_base: logit ${disben} i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
margins r.trend@i.country_alph, post	
	marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) xlabel(, format(%3.2f))  ///
		title("") xtitle("Bottom health tertile") ytitle("")		///
		note("") name(disben_1tert, replace)

eststo disben_base: logit ${disben} i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert!=1 [pw=${weight}], cluster(mergeid)
margins r.trend@i.country_alph, post	
	marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) yscale(off) xlabel(, format(%3.2f))  ///
		title("") xtitle("Upper health tertiles") ytitle("")		///
		note("") name(disben_2_3tert, replace)

	graph combine disben_1tert disben_2_3tert, xcommon xsize(8) title("Change in disability benefit receipt", margin(medium))	
	graph export "${boheimleoni_graphs}\1.c BBG_disben_trendbycountry.png", width(800) height(600) as(png) replace	

preserve	
	recode Htert (3=1) (2=1) (1=2)
		logit ${disben} i.Htert##i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit [pw=${weight}], cluster(mergeid)
			margins r.Htert#r.trend@i.country_alph if e(sample), post	
			marginsplot, horizontal /*unique*/ xline(0) recast(scatter) yscale(reverse) title("") xtitle("Change in health gap in disability benefit receipt over time") ytitle("") xlabel(,format(%3.2f))
				graph export "${boheimleoni_graphs}\1.d BBG_disben_gaptrend.png", width(800) height(600) as(png) replace
restore		
		
//////////////////////////////////////////
// 2. DIS BEN SPLIT BY WORK STATUS
//////////////////////////////////////////

// Level overall
graph hbar benvwork2 benvwork3 if ~missing(benvwork3) & $age_limit [pw=${weight}], over(country2) stack ///
	legend(label(1 "Not working") label(2 "Working")) title("Disability benefit claims by work status")
	graph export "${boheimleoni_graphs}\2a. BBG_disben_byworkstatus.png", width(800) height(600) as(png) replace
 
// Trend by country
logit benvwork2 i.country_alph##i.trend age age_sq rmale if $age_limit [pw=${weight}], cluster(mergeid)
	margins r.trend@i.country_alph, post	
		marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) xlabel(, format(%3.2f))  ///
			title("") xtitle("{bf: Claiming but not working}" " (percentage point change)", margin(l=4 r=1 t=3)) ytitle("")	name(disben_nowork, replace)
		graph close
logit benvwork3 i.country_alph##i.trend age age_sq rmale if $age_limit [pw=${weight}], cluster(mergeid)
	margins r.trend@i.country_alph, post	
		marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) xlabel(, format(%3.2f))  yscale(off) ///
			title("") xtitle("{bf: Claiming while working}" " (percentage point change)", margin(l=4 r=1 t=3)) ytitle("")	name(disben_work, replace)
		graph close
graph combine disben_nowork disben_work, xcommon xsize(8) title("Change from w1-2 to w5-6 in disability benefit receipt", margin(medium))
graph export "${boheimleoni_graphs}\2b. BBG_disben_trend_byworkstatus.png", width(800) height(600) as(png) replace


//////////////////////////////////////////
// 3. WORK HOURS SPLIT BY WORK STATUS
//////////////////////////////////////////

recode rworktype (1=2)			// Merging all jobs <15hrs/wk
tab rworktype, gen(rworktype)

// Level overall
capture which grc1leg
if _rc~=0	net install grc1leg, from(http://www.stata.com/users/vwiggins)
graph hbar rworktype1 rworktype2 rworktype3 rworktype4 if $age_limit & Htert==1 [pw=${weight}], over(country_alph) stack ///
	legend(label(1 "Not working") label(2 "Working <15hrs/wk") label(3 "Working 16-29hrs/wk") label(4 "Working 30+hrs/wk") ) 	///
	title("Poorest health tertile") name(hours_badhlth, replace) yscale(off)
graph hbar rworktype1 rworktype2 rworktype3 rworktype4 if $age_limit & Htert==3 [pw=${weight}], over(country_alph) stack ///
	legend(label(1 "Not working") label(2 "Working <15hrs/wk") label(3 "Working 16-29hrs/wk") label(4 "Working 30+hrs/wk") ) 	///
	title("Best health tertile") name(hours_goodhlth, replace) yscale(off) 
graph close _all
grc1leg hours_badhlth hours_goodhlth, title("Work status split by hours per week") xsize(12)
graph export "${boheimleoni_graphs}\3a. BBG_workhours.png", width(800) height(600) as(png) replace

 
// Trend by country
/* For working
	gen rand = runiform()
	keep if rand<0.1
*/
local label1 "Not working"
local label2 "Working <15hrs/wk"
local label3 "Working 16-29hrs/wk"
local label4 "Working 30+hrs/wk"

/*
forvalues i = 1/4 {
	logit rworktype`i' i.country_alph##i.trend age rmale if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
		margins r.trend@i.country_alph, post	
			if  inlist(`i',2,4)		local xscale "xlabel(, alternate)"	
			if ~inlist(`i',2,4)		local xscale "xscale(off)"	
			marginsplot, unique yline(0) recast(scatter) ylabel(, format(%3.1f))  `xscale' ///
				title("") ytitle("{bf: `label`i''}") xtitle("")	name(worktype`i', replace)
			graph close
/**/ }
graph combine worktype1 worktype2 worktype3 worktype4, ycommon xsize(8) cols(2) rows(2) colfirst ///
	title("Change in employment split by work hours," "from w1-2 to w5-6 among poorest health tertile", margin(medium))
graph export "${boheimleoni_graphs}\3b. BBG_workhours_trend.png", width(1000) height(600) as(png) replace
*/

forvalues i = 1/4 {
	logit rworktype`i' i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
		margins r.trend@i.country_alph, post	
			if  inlist(`i',2,4)		local xscale "xlabel(, alternate)"	
			if ~inlist(`i',2,4)		local xscale "xscale(off)"	
			marginsplot, unique yline(0) recast(scatter) ylabel(, format(%3.1f))  `xscale' ///
				title("") ytitle("{bf: `label`i''}") xtitle("")	name(worktype`i', replace) 	
			graph close
/**/ }
graph combine worktype1 worktype2 worktype3 worktype4, ycommon xsize(8) cols(2) rows(2) colfirst ///
	title("Change in employment split by work hours," "from w1-2 to w5-6 among poorest health tertile", margin(medium))
graph export "${boheimleoni_graphs}\3b. BBG_workhours_trend.png", width(1000) height(600) as(png) replace

graph close


//////////////////////////////////////////////////////////////////////////
// 4. Graphs with labour force status, by country and wave (for Appendix)
//////////////////////////////////////////////////////////////////////////
		
preserve

egen OK = anymatch(country), values(11 12 13 16 18 20 51 61)
keep if OK
drop OK

#delimit cr
foreach wave in 1 2 4 5 6 {  
	local value_label: label (wave) `wave' 
#delimit ;
graph bar (count) if $age_limit & wave==`wave' [aw=$weight],
	over(lbrf_new, 
		relabel(
			1 "Employed"
			2 "Unemployed"
			3 "Retired"
			4 "Sick/disabled"
			5 "Homemaker"
		))
		
	over(country, sort(1) descending label(angle(forty_five)))
	asyvars
	stack
	percent
	ytitle("%", orientation(horizontal))
	ylabel(, angle(horizontal))
	title("Current labour market status - `value_label'")
	subtitle("of respondents between 50 and regular retirement age")
	scale(0.8)
	note("Notes: All figures are population weighted");
#delimit cr
graph export "${boheimleoni_graphs}\00a.LMstatus_`wave'.png", width(800) height(600) as(png) replace
} 

#delimit ;
graph bar (count) if $age_limit & (wave==1 | wave==6) [aw=$weight],
	over(lbrf_new, 
		relabel(
			1 "Employed"
			2 "Unemployed"
			3 "Retired"
			4 "Sick/disabled"
			5 "Homemaker"
		))
		
	over(wave)
	over(country, sort(1) descending label(angle(forty_five)))
	asyvars
	stack
	percent
	ytitle("%", orientation(horizontal))
	ylabel(, angle(horizontal))
	title("Current labour market status - `value_label'")
	subtitle("of respondents between 50 and regular retirement age")
	scale(0.8)
	note("Notes: All figures are population weighted. Netherlands waves 5 coded as wave 6.");
#delimit cr
graph export "${boheimleoni_graphs}\00b.LMstatusW1W6.png", width(800) height(600) as(png) replace

restore


//////////////////////////////////////////////////////////////////////////
// 5. Fine-grain graphs for employment share along the health distribution
//////////////////////////////////////////////////////////////////////////

preserve

egen OK = anymatch(country), values(11 13 51 61)
keep if OK
drop OK

global health "c_pvw10"

*version with prediction, deciles/percentiles and lpoly
#delimit ;
twoway
	(lpoly injobpr_c $health [aw=$weight ] if $age_limit & wave==1, legend(lab(1 "2004/5")) clwidth(medthick)) || (lpoly injobpr_c $health [aw=$weight] if $age_limit & wave==6, legend(lab(2 "2014/15")) clwidth(medthick)),
	xtitle("Deciles of latent health indicator")
	ytitle("Employment rate (in %)")
		by(country,
		scale(0.7)
note(""))
;
graph export "${boheimleoni_graphs}\4a.cntr_W1W6_$health.png", width(800) height(600) as(png) replace;
#delimit cr

restore


preserve

egen OK = anymatch(country), values(12 16 18 20)
keep if OK
drop OK

global health "c_pvw10"

*version with prediction, deciles/percentiles and lpoly
#delimit ;
twoway
	(lpoly injobpr_c $health [aw=$weight ] if $age_limit & wave==1, legend(lab(1 "2004/5")) clwidth(medthick)) || (lpoly injobpr_c $health [aw=$weight] if $age_limit & wave==6, legend(lab(2 "2014/15")) clwidth(medthick)),
	xtitle("Deciles of latent health indicator")
	ytitle("Employment rate (in %)")
		by(country,
		scale(0.7)
note(""))
;
graph export "${boheimleoni_graphs}\4b.cntr_W1W6_$health.png", width(800) height(600) as(png) replace;
#delimit cr

restore


preserve

egen OK = anymatch(country), values(12 14 15 16 17 18 19 20 23)
keep if OK
drop OK

	recode wave (5=6) if country==14	//	fill in wave 5 for missing wave 6, Netherlands

global health "c_pvw10"

*version with prediction, deciles/percentiles and lpoly
#delimit ;
twoway
	(lpoly injobpr_c $health [aw=$weight ] if $age_limit & wave==1, legend(lab(1 "2004/5")) clwidth(medthick)) || (lpoly injobpr_c $health [aw=$weight] if $age_limit & wave==6, legend(lab(2 "2014/15")) clwidth(medthick)),
	xtitle("Deciles of latent health indicator")
	ytitle("Employment rate (in %)")
		by(country,
		scale(0.7)
note(""))
;
graph export "${boheimleoni_graphs}\4c.cntr_W1W6_$health.png", width(800) height(600) as(png) replace;
#delimit cr

restore


**/ Test: Same as above, but with comparison between trend1/2 instead of wave1/6

preserve

egen OK = anymatch(country), values(11 13 51 61)
keep if OK
drop OK

global health "c_pvw10"

*version with prediction, deciles/percentiles and lpoly
#delimit ;
twoway
	(lpoly injobpr_c $health [aw=$weight ] if $age_limit & trend==1, legend(lab(1 "2004/7")) clwidth(medthick)) || (lpoly injobpr_c $health [aw=$weight] if $age_limit & trend==2, legend(lab(2 "2012/15")) clwidth(medthick)),
	xtitle("Deciles of latent health indicator")
	ytitle("Employment rate (in %)")
		by(country,
		scale(0.7)
note(""))
;
graph export "${boheimleoni_graphs}\4d.cntr_W1W6_$health.png", width(800) height(600) as(png) replace;
#delimit cr

restore


preserve

egen OK = anymatch(country), values(12 16 18 20)
keep if OK
drop OK

global health "c_pvw10"

*version with prediction, deciles/percentiles and lpoly
#delimit ;
twoway
	(lpoly injobpr_c $health [aw=$weight ] if $age_limit & trend==1, legend(lab(1 "2004/7")) clwidth(medthick)) || (lpoly injobpr_c $health [aw=$weight] if $age_limit & trend==2, legend(lab(2 "2012/15")) clwidth(medthick)),
	xtitle("Deciles of latent health indicator")
	ytitle("Employment rate (in %)")
		by(country,
		scale(0.7)
note(""))
;
graph export "${boheimleoni_graphs}\4e.cntr_W1W6_$health.png", width(800) height(600) as(png) replace;
#delimit cr

restore


preserve

egen OK = anymatch(country), values(12 14 15 16 17 18 19 20 23)
keep if OK
drop OK

	recode wave (5=6) if country==14	//	fill in wave 5 for missing wave 6, Netherlands

global health "c_pvw10"

*version with prediction, deciles/percentiles and lpoly
#delimit ;
twoway
	(lpoly injobpr_c $health [aw=$weight ] if $age_limit & trend==1, legend(lab(1 "2004/7")) clwidth(medthick)) || (lpoly injobpr_c $health [aw=$weight] if $age_limit & trend==2, legend(lab(2 "2012/15")) clwidth(medthick)),
	xtitle("Deciles of latent health indicator")
	ytitle("Employment rate (in %)")
		by(country,
		scale(0.7)
note(""))
;
graph export "${boheimleoni_graphs}\4f.cntr_W1W6_$health.png", width(800) height(600) as(png) replace;
#delimit cr

restore



////////////////////////////////
// 6. Retention vs. recruitment
////////////////////////////////


** Recruitment - previous LM status, tenure 

preserve

recode wave (1=2) if survey=="ELSA"

foreach ctry in 11 12 13 16 18 20 51 61 {
	
	local value_label : label (country) `ctry'
		ciplot mobile [aw=$weight] if $age_limit & wave==2 & country==`ctry', ///
		by(Htert) title("`value_label'")	ytitle("In % of employed respondents", size(large))  xtitle(, size(medlarge)) scale(0.7)	saving(`ctry', replace)

}
graph combine 11.gph 12.gph 13.gph 18.gph, title("Employees with job change since last wave - W2") ycommon
graph export "${boheimleoni_graphs}\R1a.mobile1_W2.png", width(800) height(600) as(png) replace

graph combine 20.gph 16.gph 51.gph 61.gph, title("Employees with job change since last wave - W2") ycommon
graph export "${boheimleoni_graphs}\R1b.mobile2_W2.png", width(800) height(600) as(png) replace

restore

*****

preserve

recode wave (3=2) if survey=="ELSA"

foreach ctry in 11 12 13 16 18 20 51 61 {
	
	local value_label : label (country) `ctry'
		ciplot mobile [aw=$weight] if $age_limit & wave==6 & country==`ctry', ///
		by(Htert) title("`value_label'")	ytitle("In % of employed respondents", size(large))  xtitle(, size(medlarge)) scale(0.7)	saving(`ctry', replace)

}
graph combine 11.gph 12.gph 13.gph 18.gph, title("Employees with job change since last wave - W6") ycommon
graph export "${boheimleoni_graphs}\R1c.mobile1_W6.png", width(800) height(600) as(png) replace

graph combine 20.gph 16.gph 51.gph 61.gph, title("Employees with job change since last wave - W6") ycommon
graph export "${boheimleoni_graphs}\R1d.mobile2_W6.png", width(800) height(600) as(png) replace

*****

ciplot mobile [aw=$weight] if $age_limit & wave==6 & Htert_1==1, ///
		by(country) title("Bottom health tertile", size(large))	ytitle("In % of employed respondents", size(large)) xtitle("") xlabel(,labsize(medium) angle(45)) scale(0.7)	saving(bottom6, replace)

ciplot mobile [aw=$weight] if $age_limit & wave==6 & Htert_1==3, ///
		by(country) title("Top health tertile", size(large))	ytitle("In % of employed respondents", size(large)) xtitle("") xlabel(,labsize(medium) angle(45)) scale(0.7)	saving(top6, replace)

ciplot mobile [aw=$weight] if $age_limit & wave==2 & Htert_1==1, ///
		by(country) title("Bottom health tertile", size(large))	ytitle("In % of employed respondents", size(large)) xtitle("") xlabel(,labsize(medium) angle(45)) scale(0.7)	saving(bottom2, replace)

ciplot mobile [aw=$weight] if $age_limit & wave==2 & Htert_1==3, ///
		by(country) title("Top health tertile", size(large))	ytitle("In % of employed respondents", size(large)) xtitle("") xlabel(,labsize(medium) angle(45)) scale(0.7)	saving(top2, replace)

		graph combine bottom2.gph top2.gph bottom6.gph top6.gph, title("Job change since last wave - W2 (above) and W6 (below)") ycommon
graph export "${boheimleoni_graphs}\R1e.jbch_health_W2W6.png", width(800) height(600) as(png) replace
		
restore		
		
*****

preserve

recode wave (3=2) if survey=="ELSA"

#delimit ;
graph bar (count) if $age_limit & injob==1 & Htert==1 & (wave==2 | wave==6) [aw=$weight],		
			
			over(cont_emp, 
		relabel(
			1 "Employed in same job"
			2 "Employed, job change"
			3 "Not employed in previous wave"
		))

		over(wave) 
		
		over(country, label(angle(forty_five)))
	asyvars
	stack
	percent
	ytitle("%", orientation(horizontal))
	ylabel(, angle(horizontal))
	title("Job status in previous W of those employed in W2/W6")
	subtitle("Bottom tertile of health distribution in current wave")
	scale(0.8)
	note("Notes: All figures are population weighted");
#delimit cr	

graph export "${boheimleoni_graphs}\R3.job_cont_W_T1.png", width(800) height(600) as(png) replace

** Retention - LM status in next wave

#delimit ;
graph bar (count) if w1pensionage==0 & injob==1 & Htert==1 & (wave==1 | wave==5) [aw=$weight],		
			
			over(w1cont_emp, 
		relabel(
			1 "Employed in same job"
			2 "Employed, job change"
			3 "Not employed in next wave"
		))

		over(wave) 
		
		over(country, label(angle(forty_five)))
	asyvars
	stack
	percent
	ytitle("%", orientation(horizontal))
	ylabel(, angle(horizontal))
	title("Job status in next W of those employed in W1/W5")
	subtitle("Bottom tertile of health distribution")
	scale(0.8)
	note("Notes: All figures are population weighted");
#delimit cr	

graph export "${boheimleoni_graphs}\R4.job_cont_W1W5_1Temp.png", width(800) height(600) as(png) replace

**

#delimit ;
graph bar (count) if w1pensionage==0 & Htert==1 & (wave==1 | wave==5) [aw=$weight],		
			
			over(w1cont_emp, 
		relabel(
			1 "Employed in same job"
			2 "Employed, job change"
			3 "Employed only in this wave"
			4 "Employed only in next wave"
			5 "Never employed"
		))

		over(wave) 
		
		over(country, label(angle(forty_five)))
	asyvars
	stack
	percent
	ytitle("%", orientation(horizontal))
	ylabel(, angle(horizontal))
	title("Job status in next W, all persons from W1/W5 within pension age in next W")
	subtitle("Bottom tertile of health distribution")
	scale(0.8)
	note("Notes: All figures are population weighted");
#delimit cr	

graph export "${boheimleoni_graphs}\R5.job_cont_W1W5_1Temp.png", width(800) height(600) as(png) replace

restore


** Recruitment - LM status in next wave of those not employed 

preserve

keep if inlist(country, 13, 51, 61, 20, 11, 18, 12, 16)		

recode wave (0=1) (3=2) if survey=="ELSA"

#delimit cr
	#delimit ;
graph bar (count) if w1pensionage==0 & (wave==1 | wave==5) & injob==0 & Htert==1 [aw=$weight],
	over(lfsw1, 
		relabel(
			1 "Employed"
			2 "Unemployed"
			3 "Retired"
			4 "Sick/disabled"
			5 "Homemaker"
		))
	
		over(wave,
			relabel(
			1 "W1"
			2 "W5"
		))
	
	over(country, sort(1) descending label(angle(forty_five)))
	
	asyvars
	stack
	percent
	ytitle("%", orientation(horizontal))
	ylabel(, angle(horizontal))
	title("Labour market status in next W of those NOT employed in W1/W5")
	subtitle("of respondents IN BOTTOM HEALTH TERTILE (50 to ret age in next W)")
	scale(0.8)
	note("Notes: All figures are population weighted. ALL persons not employed in W1/W5 and within retirement age in W2/W6 included in the sample")
	saving(W`wave', replace);
#delimit cr
graph export "${boheimleoni_graphs}\R7b.next_LMs_1T_W1W5.png", width(800) height(600) as(png) replace

#delimit cr
	#delimit ;
graph bar (count) if w1pensionage==0 & (wave==1 | wave==5) & injob==0 & Htert==1 [aw=$weight],
	over(w1injob, 
		relabel(
			1 "Not employed"
			2 "Employed"
		))
	
		over(wave,
			relabel(
			1 "W1"
			2 "W5"
		))
	
	over(country, sort(1) descending label(angle(forty_five)))
	
	asyvars
	stack
	percent
	ytitle("%", orientation(horizontal))
	ylabel(, angle(horizontal))
	title("Labour market status in next W of those NOT employed in W1/W5")
	subtitle("of respondents IN BOTTOM HEALTH TERTILE (50 to ret age in next W)")
	scale(0.8)
	note("Notes: All figures are population weighted. ALL persons not employed in W1/W5 and within retirement age in W2/W6 included in the sample")
	saving(W`wave', replace);
#delimit cr
graph export "${boheimleoni_graphs}\R7b.b.next_LMs_1T_W1W5.png", width(800) height(600) as(png) replace

restore


**Same as previous one, but excluding those who are homemakers or already retired in W1/W5

preserve

recode wave (0=1) (3=2) if survey=="ELSA"

keep if inlist(country, 13, 51, 61, 20, 11, 18, 12, 16)		

#delimit cr
	#delimit ;
graph bar (count) if w1pensionage==0 & (wave==1 | wave==5) & injob==0 & retired==0 & home==0 & Htert==1 [aw=$weight],
	over(lfsw1, 
		relabel(
			1 "Employed"
			2 "Unemployed"
			3 "Retired"
			4 "Sick/disabled"
			5 "Homemaker"
		))
	
		over(wave,
			relabel(
			1 "W1"
			2 "W5"
		))
	
	over(country, sort(1) descending label(angle(forty_five)))
	
	asyvars
	stack
	percent
	ytitle("%", orientation(horizontal))
	ylabel(, angle(horizontal))
	title("Labour market status in following W of those NOT employed in W1/W5")
	subtitle("of respondents IN BOTTOM HEALTH TERTILE (50 to ret age in next W)")
	scale(0.8)
	note("Notes: All figures are population weighted. Homemakers and retirees in W `value_label' excluded from the sample")
	saving(W`wave', replace);
#delimit cr
graph export "${boheimleoni_graphs}\R7c.next_LMs_1T_W1W5.png", width(800) height(600) as(png) replace

#delimit cr
	#delimit ;
graph bar (count) if w1pensionage==0 & (wave==1 | wave==5) & injob==0 & retired==0 & home==0 & Htert==1 [aw=$weight],
	over(w1injob, 
		relabel(
			1 "Not employed"
			2 "Employed"
		))
	
		over(wave,
			relabel(
			1 "W1"
			2 "W5"
		))
	
	over(country, sort(1) descending label(angle(forty_five)))
	
	asyvars
	stack
	percent
	ytitle("%", orientation(horizontal))
	ylabel(, angle(horizontal))
	title("Labour market status in following W of those NOT employed in W1/W5")
	subtitle("of respondents IN BOTTOM HEALTH TERTILE (50 to ret age in next W)")
	scale(0.8)
	note("Notes: All figures are population weighted. Homemakers and retirees in W1/5 excluded from the sample")
	saving(W`wave', replace);
#delimit cr
graph export "${boheimleoni_graphs}\R7c.b.next_LMs_1T_W1W5.png", width(800) height(600) as(png) replace

restore


**Tenure

eststo tenure_base: reg rjcten i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
margins r.trend@i.country_alph, post	
	marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) xlabel(, format(%3.2f))  ///
		title("") xtitle("Bottom health tertile") ytitle("")		///
		note("") name(tenure_ch_1, replace)

eststo tenure_base: reg rjcten i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert!=1 [pw=${weight}], cluster(mergeid)
margins r.trend@i.country_alph, post	
	marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) xlabel(, format(%3.2f))  ///
		title("") xtitle("Upper health tertiles") ytitle("")		///
		note("") name(tenure_ch_2, replace)

	graph combine tenure_ch_1 tenure_ch_2, xcommon xsize(8) title("Change in average tenure", margin(medium))	
	graph export "${boheimleoni_graphs}\R8.a tenure_trendbycountry.png", width(800) height(600) as(png) replace	


foreach ctry in 11 12 13 16 18 20 51 61 {
	
	local value_label : label (country) `ctry'
		ciplot rjcten [aw=$weight] if $age_limit & country==`ctry' & Htert==1, ///
		by(trend) title("`value_label'") xtitle("") ytitle("Average tenure (in years)", size(large)) note("") saving(`ctry', replace)
}

graph combine 11.gph 13.gph 51.gph 61.gph, title("Average tenure - 2004/7 to 2012/5 - Poor health") ycommon
	graph export "${boheimleoni_graphs}\R8.b tenure_level1Tbycountry.png", width(800) height(600) as(png) replace			

graph combine 12.gph 16.gph 18.gph 20.gph, title("Average tenure - 2004/7 to 2012/5 - Poor health") ycommon
	graph export "${boheimleoni_graphs}\R8.c tenure_level1Tbycountry.png", width(800) height(600) as(png) replace	


reg rjcten i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
	margins country_alph, over(trend) 
	marginsplot, horizontal unique recast(scatter) yscale(reverse) title("") xtitle("Average tenure in years, bottom health tertile") ytitle("") legend(order (3 "2004/7" 4 "2012/15"))
		graph export "${boheimleoni_graphs}\R8.d tenure_levels1T.png", width(800) height(600) as(png) replace		

		
ciplot rjcten [aw=$weight] if $age_limit & trend==1 & Htert==1,  ///
		by(country) title("")	ytitle("Average tenure (in years)", size(large))  xtitle(, size(medlarge)) scale(0.7) name(tenure_lev_1, replace)

ciplot rjcten [aw=$weight] if $age_limit & trend==2 & Htert==1,  ///
		by(country) title("")	ytitle("Average tenure (in years)", size(large))  xtitle(, size(medlarge)) scale(0.7) name(tenure_lev_2, replace)

graph combine tenure_lev_1 tenure_lev_2 , xcommon xsize(8) title("Average tenure, 2004/7 and 2012/5, bottom health tertile", margin(medium))	
	graph export "${boheimleoni_graphs}\R8.e tenure_level1Tbycountry.png", width(800) height(600) as(png) replace			

	
preserve
	recode Htert (3=2)	
		eststo tenure_base: reg rjcten i.Htert##i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit [pw=${weight}], cluster(mergeid)
			margins r.Htert#r.trend@i.country_alph if e(sample), post
			marginsplot, horizontal /*unique*/ xline(0) recast(scatter) yscale(reverse) title("") xtitle("Change in health tenure gap over time (in years)") ytitle("") xscale(r(-10 10)) 		
				graph export "${boheimleoni_graphs}\R8.f gaptenuretrend.png", width(800) height(600) as(png) replace
restore

				
*_____________________________________________________________________________________________________________________________________________________
*
* Step 5: Generate tables and carry out sensitivity checks for use of different data/specifications 
*_____________________________________________________________________________________________________________________________________________________

//////////////////////////////////////////
// 0. Descriptives
////////////////////////////////////////// 

drop country_waveN
egen country_waveN = group(country_alph wave), label   // replace existing country_waveN to have a continuous numerical country-wave identifier
tab country_waveN, nolab
tab country_waveN

tabstat age if $age_limit & mainsample==1 [aw=${weight}], by(country_waveN) s(n mean min max)
tabstat rmale if $age_limit & mainsample==1 [aw=${weight}], by(country_waveN) s(n mean)
tabstat injob if $age_limit & mainsample==1 [aw=${weight}], by(country_waveN) s(n mean)

tabstat ret_age if mainsample==1 & wave==1 [aw=${weight}], by(country_alph) s(min max mean)
tabstat ret_age if mainsample==1 & wave==5 [aw=${weight}], by(country_alph) s(min max mean)
tabstat ret_age if mainsample==1 & wave==6 [aw=${weight}], by(country_alph) s(min max mean)


//////////////////////////////////////////
// 1. Different versions of Tables for trends in LEVEL and GAP
////////////////////////////////////////// 

/* Compute the following Tables once using our main latent health index, once the latent health index calculated without BMI. 
   Second steps need activation of lines 85 to 90, substituting pca_cntr_nbmi for pca_cntr and so on  */

**Version used by Ben when checking sensitivity to multiple imputations (LOGIT)
eststo mainmode: logit rworknew i.Htert##i.country_alph##i.trend age rmale if $age_limit [pw=${weight}], cluster(mergeid)
margins r3.Htert#r.trend@i.country_alph if e(sample), predict(xb) post
estimates restore mainmode
margins r.trend@i.country_alph if e(sample), at(Htert==1) predict(pr) post

**Version that is consistent with graphs (OLS)
eststo mainmode: reg injob i.Htert##i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit  [pw=${weight}], cluster(mergeid)
margins r3.Htert#r.trend@i.country_alph if e(sample)
estimates restore mainmode
margins r.trend@i.country_alph if e(sample), at(Htert==1) 

**Adapted version of Ben's synthax, used as sensitivity analysis LOGIT vs OLS  
eststo mainmode: logit injob i.Htert##i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit [pw=${weight}], cluster(mergeid)
margins r3.Htert#r.trend@i.country_alph if e(sample), predict(pr) post
estimates restore mainmode
margins r.trend@i.country_alph if e(sample), at(Htert==1) predict(pr) post


//////////////////////////////////////////
// 2. Other Tables to be included in the paper
//////////////////////////////////////////


**Graph 1.0 BBG_disben_levelsbycountry (Disability benefit receipt)
eststo disben_base: logit ${disben} i.country_alph c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
	margins i.country_alph, post	
eststo disben_base: logit ${disben} i.country_alph c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert!=1 [pw=${weight}], cluster(mergeid)
	margins i.country_alph, post	


**Graph 1.a/b BBG_disben_trendbycountry (Disability benefit receipt)
eststo disben_base: logit ${disben} i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
	margins r.trend@i.country_alph, post	
eststo disben_base: logit ${disben} i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert!=1 [pw=${weight}], cluster(mergeid)
	margins r.trend@i.country_alph, post

	
*LM Status
tab lbrf_new, gen(rlfs)
label variable rlfs1 "employed" 
label variable rlfs2 "unemployed" 
label variable rlfs3 "retired" 
label variable rlfs4 "disab" 
label variable rlfs5 "home"

tabstat rlfs1 rlfs2 rlfs3 rlfs4 rlfs5 if $age_limit & Htert==1 & wave==1 [aw=${weight}], by(country_alph) s(mean)
tabstat rlfs1 rlfs2 rlfs3 rlfs4 rlfs5 if $age_limit & Htert==1 & wave==5 [aw=${weight}], by(country_alph) s(mean)
tabstat rlfs1 rlfs2 rlfs3 rlfs4 rlfs5 if $age_limit & Htert==1 & wave==6 [aw=${weight}], by(country_alph) s(mean)

table country rworktype if $age_limit & Htert==1 [aw=${weight}]


*R4
preserve
 recode wave (3=2) if survey=="ELSA"

tab w1cont_emp, gen(jobw)
label variable jobw1 "Employed in same job" 
label variable jobw2 "Employed, job change" 
label variable jobw3 "Not employed in next wave" 

tabstat jobw1 jobw2 jobw3 if w1pensionage==0 & injob==1 & Htert==1 & (wave==1 | (wave==2 & country==61)) [aw=$weight],  by(country_alph) s(mean)		
tabstat jobw1 jobw2 jobw3 if w1pensionage==0 & injob==1 & Htert==1 & (wave==5  | (wave==4 & country==14)) [aw=$weight],  by(country_alph) s(mean)		

restore


*R5b
preserve
 recode wave (3=2) if survey=="ELSA"
 
tab w1cont_emp, gen(jobw)
 label variable jobw1 "Employed in same job" 
 label variable jobw2 "Employed, job change"  
 label variable jobw3 "Employed only this wave"  
 label variable jobw4 "Employed only next wave" 
 label variable jobw5 "Never employed"

	tabstat jobw1 jobw2 jobw3 jobw4 jobw5 if w1pensionage==0 & Htert==1 & (wave==1 | (wave==2 & country==61)) [aw=$weight], by(country_alph) s(mean)
	tabstat jobw1 jobw2 jobw3 jobw4 jobw5 if w1pensionage==0 & Htert==1 & (wave==5 | (wave==4 & country==14)) [aw=$weight], by(country_alph) s(mean)
restore


*R7c
tab lfsw1, gen(rlfw)
label variable rlfw1 "employed" 
label variable rlfw2 "unemployed" 
label variable rlfw3 "retired" 
label variable rlfw4 "disab" 
label variable rlfw5 "home"

tabstat rlfw1 rlfw2 rlfw3 rlfw4 rlfw5 if w1pensionage==0 & (wave==1 | (wave==2 & country==61)) & injob==0 & retired==0 & home==0 & Htert==1 [aw=$weight], by(country_alph) s(mean)
tabstat rlfw1 rlfw2 rlfw3 rlfw4 rlfw5 if w1pensionage==0 & wave==5 & injob==0 & retired==0 & home==0 & Htert==1 [aw=$weight], by(country_alph) s(mean)


*R8a
eststo tenure_base: reg rjcten i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
	margins r.trend@i.country_alph, post	

eststo tenure_base: reg rjcten i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert!=1 [pw=${weight}], cluster(mergeid)
	margins r.trend@i.country_alph, post	


**Working hours
recode rworktype (1=2)			// Merging all jobs <15hrs/wk
replace rworktype=. if missing(rworktype)

**Graph 3a
preserve

keep if inlist(country, 13, 51, 61, 20, 11, 18, 12, 16)		// limited to country selection 

tabstat rworktype1 rworktype2 rworktype3 rworktype4 if $age_limit & Htert==1 [aw=${weight}], by(country) s(mean)
table country rworktype if $age_limit & Htert==1 [aw=${weight}]

tabstat rworktype1 rworktype2 rworktype3 rworktype4 if $age_limit & Htert==3 [aw=${weight}], by(country) s(mean)
table country rworktype if $age_limit & Htert==3 [aw=${weight}]

**Graph 3b
	local label1 "Not working"
	local label2 "Working <15hrs/wk"
	local label3 "Working 16-29hrs/wk"
	local label4 "Working 30+hrs/wk"
forvalues i = 1/4 {
 eststo mainmode: logit rworktype`i' i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit & Htert==1 [pw=${weight}], cluster(mergeid)
		margins r.trend@i.country_alph, post	
}		 
restore

	
	
	

