**********************************************************************
* FILE NOTE:
* Original version from early 2018 code, created 2018/1/26
* This updated version from the file bbl_2017_analysis_v1_clean, emailed 2018-03-18 [dated 26 Feb 2018]
**********************************************************************

*_____________________________________________________________________________________________________________________________________________________
*
* Getting this to work on BBG computer
*_____________________________________________________________________________________________________________________________________________________

// Setting the overall file locations
do "C:\Users\bpb\Dropbox\Disability work\ESRC Future Leaders Disability\Phase 1 (Dis Emp Rates) - Intl\ELSA-SHARE-HRS\0_master.do"
global boheimleoni_latestdo		"${dodir}\Boheim-Leoni reference files\2018-05-10\Latest do files"
global boheimleoni_graphs		"${dodir}\Boheim-Leoni reference files\z. Latest charts"
* Used in the multiple imputation .do file
global inputDir 			"${hrsdir}"
global outputDir 			"${hrsdir}"
global graphDir				"${boheimleoni_graphs}\0. MI charts"
global graphtmpDir 			"${boheimleoni_graphs}\0. MI charts"
global tempDir 				"${boheimleoni_graphs}\0. MI charts"


// Other things that are needed
capture which mdesc					// Thomas & Rene's cleaning relies on this command
	if _rc~=0		net install mdesc, from(http://fmwww.bc.edu/RePEc/bocode/m)
capture which ciplot				// Thomas & Rene's analysis relies on this command
	if _rc~=0		net install ciplot, from(http://fmwww.bc.edu/RePEc/bocode/c)
exit


*_____________________________________________________________________________________________________________________________________________________
*
* Imputation
* This was previously a separate .do file so need to bring this in here
*_____________________________________________________________________________________________________________________________________________________


do "${dodir}\Boheim-Leoni reference files\10_boheimleoni_part1_imputed (MI).do"


*_____________________________________________________________________________________________________________________________________________________
*
* BBG analysis using Boheim-Leoni dataset taken from the Boheim-Leoni code
* 29/5/2018
*_____________________________________________________________________________________________________________________________________________________

use "${hrsdir}\bbl_2017_analysis.dta", clear


/////////////////////////
// Final cleaning
// (This is taken from 2.bbl_2017_analysis, after the data file is saved)
drop if inlist(country, 25, 34, 35, 28, 29)  // to get rid of Israel, Slovenia, Estonia, Czech R, Poland (insufficient sample size/waves to get anything other than very wide confidence intervals)
replace wave=wave_orig-1 if survey=="ELSA" 		//	Previously only done for wave>=4
	label var wave "NEW VERSION OF WAVE (HRS=wave-6, ELSA=wave-1)"		// BBG added
recode wave (1/2=1 "w1-2")(5/6=2 "w5-6")(else=.), gen(trend)
	label var trend "Dummy for waves 1-2 vs. 5-6"
	
	
/////////////////////////
// Global
global health 		"c_pvw100"
global weight 		"rwtresp2"
global age_limit 	"age>=50 & age<=ret_age"
global pca_varlist 	"rwalk100a rlifta rpusha anyADL anyIADL rclim1a rclimsa rstoopa rdimea rsita rchaira rarmsa rhibpe rstroke rdiabe rlunge rhearte rcancre rarthre rmhcase rmhscale_Z sphus45 underw obese"
/* For the _beta .do files, this is different:
global age_limit "age>=54 & age<=65"
*/
	
	
/////////////////////////
// Descriptive stats
* Setting sample for descriptives
reg injob i.Htert##i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph if $age_limit  [pw=${weight}], cluster(mergeid)
gen mainsample=1 if e(sample)==1
gen fullsample = 1 if ~missing(Htert)		// This includes earlier waves
capture drop country_waveN
egen country_waveN = group(country_alph wave), label   // replace existing country_waveN to have a continuous numerical country-wave identifier

* Descriptive stats themselves
tabstat age if $age_limit & mainsample==1 [aw=${weight}], by(country_waveN) s(n mean min max)
tabstat rmale if $age_limit & mainsample==1 [aw=${weight}], by(country_waveN) s(n mean)
tabstat injob if $age_limit & mainsample==1 [aw=${weight}], by(country_waveN) s(n mean)
tabstat ret_age if mainsample==1 & wave==1 [aw=${weight}], by(country_alph) s(min max mean)
tabstat ret_age if mainsample==1 & wave==5 [aw=${weight}], by(country_alph) s(min max mean)
tabstat ret_age if mainsample==1 & wave==6 [aw=${weight}], by(country_alph) s(min max mean)
* My own version
table country_waveN if mainsample==1 [pw=${weight}], c(n rmale mean rmale)
table country_waveN if ${age_limit} [pw=${weight}], c(n rmale mean rmale)
* Checking disability benefit claims by wave
tabstat rbeninc2_dis if mainsample==1 [aw=${weight}], by(country_waveN) s(n mean)
tabstat rbeninc2_dis if fullsample==1 [aw=${weight}], by(country_waveN) s(n mean)
tabstat rbeninc2_dis if fullsample==1 & age<60 [aw=${weight}], by(country_waveN) s(n mean)
* To check year of each survey wave
table country_waveN, c(min year max year min riwy max riwy)
* Sample sizes
tab country_waveN if fullsample==1 & ${age_limit}
tabstat age if $age_limit & fullsample==1 [aw=${weight}], by(country_waveN) s(n mean min max)
preserve
	keep if ${age_limit} & fullsample==1
	bysort mergeidnum: gen count = _n
	tab survey count
restore


* Missing data
global pcalist_v2 = subinstr("${pca_varlist}", "underw obese", "rbmicat", .)
global pcalist_v2 = subinstr("${pcalist_v2}" , "rmhcase rmhscale_Z", "rmhscale_Z", .)
egen misscount = rowmiss(${pcalist_v2} injob) if ${age_limit}
label define missdetail 0 "0_full" 1 "1_BMI only missing" 2 "2_another var missing" 3 "3_multiple vars missing"
gen missdetail 			= 0 if misscount==0
	replace missdetail 	= 1 if misscount==1 &  missing(rbmicat)
	replace missdetail 	= 2 if misscount==1 & ~missing(rbmicat)
	replace missdetail 	= 3 if misscount>=2
	label values missdetail missdetail
svyset [pw=${weight}]
svy: tab country_waveN missdetail if $age_limit & inlist(wave, 1, 2, 5, 6), row percent format(%4.2f) stubwidth(32)

