**********************************************************************
* FILE NOTE:
* This is an adapted version of 10_boheimleoni_part1, itself based on:
	* Part 1 (health indices) from Boheim-Leoni reference files\2018-01-16 do files\bbl_2017_health_indic_2Dec.do [dated 2 Dec 2017]
	* Part 2 (cleaning) was originally from Boheim-Leoni reference files\2018-01-16 do files\bbl_2017_analysis_2Dec_part1cleaning.do [dated 2 Dec 2017]
	* Updated version from bbl_2017_analysis_v1_clean, emailed 2018-03-18 [dated 26 Feb 2018]
* It excludes the Juerges indicator, and moves the general data cleaning to a different file
**********************************************************************

pause This assumes that you have previously run the master .do file
/*
do "C:\Users\bpb\Dropbox\Disability work\ESRC Future Leaders Disability\Phase 1 (Dis Emp Rates) - Intl\ELSA-SHARE-HRS\Boheim-Leoni reference files\10_boheimleoni_part0 (master).do"
*/
use "${hrsdir}\BoheimLeoniGeiger_${versno}.dta", replace

	
*_____________________________________________________________________________________________________________________________________________________
*
* PART 1: THE MULTIPLE IMPUTATION ITSELF
*_____________________________________________________________________________________________________________________________________________________

unab healthvarsB: rworknew rwalk100a rsita rchaira rstoopa rarmsa rpusha rlifta rdimea anyADL anyIADL rhibpe-rcancre rhearte sphus45
global healthvarsB1 "`healthvarsB'"					// Binary - LOGIT
global healthvarsB2 "rmhcase rclimsa rclim1a"		// Binary - LOGIT (but exc. certain vars) 
global healthvarsM "rbmicatO"						// Caterogical - MLOGIT
global healthvarsC "rmhscale_Z"						// Continuous - REG
global healthvars "${healthvarsB1} ${healthvarsB2} ${healthvarsM} ${healthvarsC}"


// Putting vars in right format
clonevar rbmicatO = rbmicat 
	recode rbmicatO (1 2=2)		// The  underweight category is just too small...
	replace rbmicatO = . if rbmi_flag~=0
	label var rbmicatO "BMI category without carryforward/backward"
	order rbmicatO, after(rbmicat)
recode ${healthvars} (missing=.)			// necessary as MI IMPUTE won't work with labelled missing codes (as these are over-written)
*recode survey_waveN (1 2=1)(4 5=2)(6 7=3), copyrest gen(imputecluster)
recode country_waveN (70 71=70)(72 73=71)(74 75=72), copyrest gen(imputecluster)
	label copy country_waveN imputecluster, replace
	label define imputecluster 70 "70_ELSA waves 1+2" 71 "71_ELSA waves 4+5" 72 "72_ELSA waves 6+7" 73 "" 74 "" 75 "", modify
	label values imputecluster imputecluster
 	label var imputecluster "Grouped survey_waveN for multiple imputation"
	order imputecluster, after(survey_waveN)
keep ${healthvars} survey-age ret_age			// Anything that's not in the imputation should be dropped to keep the space manageable...
	
	/* Checks
	bysort survey_waveN: mdesc ${healthvars}
	bysort survey_waveN: sum mergeidnum ${healthvars}, sep(0)
	capture drop miss*
	egen missingcount = rowmiss(${healthvars})
	recode missingcount(0=0)(1=1)(2=2)(3=3)(4/10=4 "4_4 to 10")(5/max=5 "5_5+"), gen(misscode)
	misstable patterns ${healthvars}, bypatterns
	misstable patterns ${healthvars} if survey=="SHARE", bypatterns
	misstable patterns ${healthvars} if survey=="ELSA" & wave~=3, bypatterns
	misstable patterns ${healthvars} if survey=="HRS", bypatterns
	tab country_waveN misscode, row nof
	*/

// First effort at imputation
cd "${hrsdir}"
mi erase imputed_data
mi set flong  				// help mi_styles##advice_flongsep - I tried this and fundamentally it was a pain to use, hence I've gone for 
mi register imputed ${healthvarsB1} ${healthvarsB2} ${healthvarsM} ${healthvarsC}
dis "{mansection MI miimputeRemarksandexamplesTheissueofperfectpredictionduringimputationofcategoricaldata:Notes on avoiding perfect prediction}"	
save "${hrsdir}\BoheimLeoniGeiger_${versno}_imputedworking.dta", replace


/* Test command
mi impute chained (logit) ${healthvarsB1} (mlogit) ${healthvarsM} (logit, omit(rmhscale_Z)) rmhcase (logit, omit(i.rclimsa)) rclim1a		///
	(logit, omit(i.rclim1a)) rclimsa (reg, omit(i.rmhcase)) ${healthvarsC} = age rmale [pw=rwtresp2] if survey~="SHARE"						///
	, dryrun by(survey)
// Checking convergence (savetrace doesn't work with by, so I've chosen the smallest cluster (10) and the smallest ELSA cluster (3))
dis "{mansection MI miimputechainedRemarksandexamplesExamples:Check convergence (see example 2)}"	// See also help mi_impute_chained##savetrace
local timestarted = "`c(current_time)' on `c(current_date)'"
mi impute chained (logit) ${healthvarsB1}  (mlogit) ${healthvarsM} (logit, omit(rmhscale_Z)) rmhcase (reg, omit(i.rmhcase)) ${healthvarsC} 	///
	 (logit, omit(i.rclimsa)) rclim1a (logit, omit(i.rclim1a)) rclimsa = age rmale [pw=rwtresp2] if survey~="SHARE"							///
	& imputecluster==3, chainonly burnin(100) savetrace(impstats, replace) rseed(19032018) augment /*noisily*/ dots 				
dis "Time started is `timestarted'; time ended is: "
	time
	* Checking the outputs of this
	use "${hrsdir}/impstats"
	tsset iter
	*local vars "rworknew rwalk100a rsita rchaira rstoopa rarmsa rpusha rlifta rdimea anyADL anyIADL rhibpe-rcancre rhearte rclimsa rclim1a rshlt rbmicatO rmhcase rmhscale_Z"
	*local vars	"rwalk100a anyIADL rbmicatO rmhcase rmhscale_Z rclim1a rclimsa"		// These are the only vars w any noticeable missingness in imputecluster==10
	local vars	"rshlt rbmicatO rmhcase rmhscale_Z"		// These are the only vars w any noticeable missingness in imputecluster==3
	foreach var in `vars' {
		tsline `var'_mean, name(gr1, replace) nodraw yscale(range (0 1))
		tsline `var'_sd,   name(gr2, replace) nodraw yscale(range (0 1))
		graph combine gr1 gr2, title(Trace plots of imputed values for `var')
		pause This is `var'
	/**/ }
	graph close _all
	* NOTES TO SELF: mostly these are fine very quickly (after normal burnin), but every now and again it's better after a burnin of 20-30 or so.
END CHECKS */


// Final imputation model, split by imputation cluster as (i) much faster & (ii) can be interrupted partway through
forvalues i = 1/72 {
	local thislabel: label imputecluster `i'
	dis "This is imputecluster `thislabel'"
	use "${hrsdir}\BoheimLeoniGeiger_${versno}_imputedworking.dta", replace
	keep if imputecluster==`i'
	local timestarted = "`c(current_time)' on `c(current_date)'"
	mi impute chained (logit) ${healthvarsB1}  (mlogit) ${healthvarsM} (logit, omit(rmhscale_Z)) rmhcase (reg, omit(i.rmhcase)) ${healthvarsC} 	///
		 (logit, omit(i.rclimsa)) rclim1a (logit, omit(i.rclim1a)) rclimsa = age rmale [pw=rwtresp2] 											///
		, add(10) rseed(19032018) burnin(10) augment /*noisily*/ dots 				// Max iterations is fine here because if models don't converge, an augmented regression will be run
	save "${hrsdir}\BoheimLeoniGeiger_${versno}_imputedcluster`i'.dta", replace
	dis _newline(3) in red "For cluster `thislabel', time started is `timestarted'; time ended is: "
	time
/**/ }
time


// Combine imputed files into a single dataset
use "${hrsdir}\BoheimLeoniGeiger_${versno}_imputedcluster1.dta", replace
mi des
forvalues i = 2/72 {
	dis "Now appending imputecluster `i' at time `c(current_time)'"
	mi append using "${hrsdir}\BoheimLeoniGeiger_${versno}_imputedcluster`i'.dta", gen(imputecluster_`i')
/**/ }
save "${hrsdir}\BoheimLeoniGeiger_${versno}_imputed.dta", replace
forvalues i = 1/72 {
	erase "${hrsdir}\BoheimLeoniGeiger_${versno}_imputedcluster`i'.dta"
/**/ }
erase "${hrsdir}\BoheimLeoniGeiger_${versno}_imputedworking.dta"
dis in red "_mi_id is an arbitrary ID" _newline(1) "_mi_miss is a flag for whether any values missing in m==0" _newline(1) "_mi_m is the imputation number"
mi des

	
	/* Checking the outputs of this
	quietly levelsof imputecluster, local(imputelevels)
	foreach cluster in `imputelevels' {
		sum _mi_miss if imputecluster==`cluster' & _mi_m==0
		mi xeq: sum wave rbmicatO if imputecluster==`cluster'
	/**/ }
	browse mergeid wave rbmicatO rmhcase survey _mi_miss _mi_m if _mi_miss==1 & _mi_m==0 & imputecluster==1
	browse mergeid wave rbmicatO rmhcase survey _mi_miss _mi_m if imputecluster==13 & mergeid=="51531944010"
	*/



*_____________________________________________________________________________________________________________________________________________________
*
* PART 1: DATA CLEANING - CREATE LATENT HEALTH INDICATORS (PCA)
* (This was previously done in a separate file)
*_____________________________________________________________________________________________________________________________________________________

use "${hrsdir}\BoheimLeoniGeiger_${versno}_imputed.dta", replace
drop imputecluster_*

// New bit for multiple imputation
set rmsg off
quietly sum _mi_m
local imputationcount = `r(max)'
local timestarted = "`c(current_time)' on `c(current_date)'"
dis _newline(5) in red "Type 't' to run test version, or 'f' to run full version", _request(_testfull)
assert inlist("`testfull'", "t", "f")
if "`testfull'"=="t"			local cntrylist "11 12"
if "`testfull'"=="f"			local cntrylist "11 12 13 14 15 16 17 18 19 20 23 25 28 29 51 61"
set rmsg on, permanently


// pca_varlist is constant for all waves (and across all country in the preferred version)
global pca_varlist 		"rwalk100a rlifta rpusha anyADL anyIADL rclim1a rclimsa rstoopa rdimea rsita rchaira rarmsa rhibpe rstroke rdiabe rlunge"
global pca_varlist 		"${pca_varlist} 	 rhearte rcancre rarthre rmhcase rmhscale_Z sphus45 rbmicat"


// Separately for each country, pooling all waves
gen pca_cntr=.
label var pca_cntr "latent health index by PVW (2013), countries separately"
forvalues imputation = 0/`imputationcount' {
	foreach ctry in `cntrylist' {
		local value_label : label (country) `ctry'
		display _newline(5) in smcl as text "These are the results for country `ctry' -> " as result "`value_label'" as text " in " as result "imputation `imputation'"
		pca $pca_varlist if age>=50 & age<=67 & country==`ctry' & _mi_m==`imputation', components(3)
			estat loadings 
			predict pc1, score
			replace pca_cntr=pc1 if !missing(pc1) & age>=50 & age<=67 & country==`ctry' & _mi_m==`imputation'
			drop pc1
	/**/ }
/**/ }


// to scale index between 1 and 0
sum pca_cntr, d	                  
replace pca_cntr=1-(pca_cntr-r(min))/(r(max) - r(min))


// Calculate percentiles (ATTENTION: percentiles within country AND WAVE (and population within statutory retirement age))
gen c_pvw100=.
label var c_pvw100 "percentile PVW index, countries & wave separately"
forvalues imputation = 0/`imputationcount' {
	foreach ctry in `cntrylist' {
		quietly levelsof imputecluster if country==`ctry'
		foreach impclust in `r(levels)' {
			local value_label : label (country) `ctry'
			display _newline(5) in smcl as text "Percentiles for country `ctry' -> " as result "`value_label' " as text "in imputecluster `impclust' in imputation `imputation'"
			xtile c_pvw100_`ctryw'_`imputation' = pca_cntr if country==`ctry' & imputecluster==`impclust' & age<=ret_age & _mi_m==`imputation', nq(100)
			replace c_pvw100=c_pvw100_`ctryw'_`imputation' if country==`ctry' & imputecluster==`impclust' & _mi_m==`imputation'
			drop c_pvw100_`ctryw'_`imputation'
		/**/						}
	/**/						}
/**/			}
dis "Time PCA version `testfull' started is `timestarted'; time ended is: "
time
dis in red _newline(5) "Note from HELP MI_SET: if you have super-varying vars (like latent PCA, "	///
	_newline(1) "which varies across imputations even for complete cases)" 				///
	_newline(1) "then help files says 'be aware that they can be stored only in " 		///
	_newline(1) "flong and flongsep data and that they never should be registered.'"

	
// Cleaning the derived health variables
// (This originally came in a separate file)
recode c_pvw100 (.=.)(1/33=1 "worst")(34/66=2 "middle")(67/100=3 "top"), gen(Htert)	// BBG slight edit of syntax here
label variable Htert "Tertile of health distribution"

	
// New file
compress
save "${hrsdir}\BoheimLeoniGeiger_${versno}_imputed_wPCA.dta", replace




*_____________________________________________________________________________________________________________________________________________________
*
* PART 2: ANALYSIS
* Originally from part2(old) by BBG
* Note: can't use GRAPH BAR / TWOWAY LPOLY - no uncertainty, so it would just use full sample or the first imputation sample (depending on preference)
*_____________________________________________________________________________________________________________________________________________________

use "${hrsdir}\BoheimLeoniGeiger_${versno}_imputed_wPCA.dta", replace
dis in red _newline(5) "Note from HELP MI_SET: if you have super-varying vars (like latent PCA, "	///
	_newline(1) "which varies across imputations even for complete cases)" 				///
	_newline(1) "then help files says 'be aware that they can be stored only in " 		///
	_newline(1) "flong and flongsep data and that they never should be registered.'"
* Globals
global weight "rwtresp2"
global age_limit "age>=50 & age<=ret_age"
* Further prep/globals
rename wave wave_orig
clonevar wave = wave_orig      	// gen new wave variable
	replace wave=wave_orig-6 if survey=="HRS"
	replace wave=wave_orig-1 if survey=="ELSA" & wave>=4
	label var wave "NEW VERSION OF WAVE (HRS=wave-6, ELSA turns 4-7 into 3-6)"		// BBG added
recode wave (1/2=1 "w1-2")(5/6=2 "w5-6")(else=.), gen(trend)
	label var trend "Dummy for waves 1-2 vs. 5-6"
gen age_sq = age*age
gen injob = rworknew  
drop rworknew
* Country labelling
numlabel countrynew, mask(#_) remove
capture drop working
decode country, gen(working)
	capture drop country_alph 
	capture label drop country_alph
label define country_alph 1 "USA", modify
label define country_alph 2 "England", modify
label define country_alph 3 "Austria", modify
label define country_alph 4 "Belgium", modify
label define country_alph 5 "Denmark", modify
label define country_alph 6 "France", modify
label define country_alph 7 "Germany", modify
label define country_alph 8 "Greece", modify
label define country_alph 9 "Italy", modify
label define country_alph 10 "Netherlands", modify
label define country_alph 11 "Spain", modify
label define country_alph 12 "Sweden", modify
label define country_alph 13 "Switzerland", modify
encode working, gen(country_alph) label(country_alph)
	label var country_alph "Country (alphabetic for graphing, no numeric codes)"
	
numlabel countrynew, mask(#_) add
set matsize 10000

		
//////////////////////////
// Models
pause This takes about 3hrs for m=10...
	capture erase miestfile.ster
	capture drop esample
	capture which mimrgns
	if _rc~=0		ssc install mimrgns
local timestarted = "`c(current_time)' on `c(current_date)'"
log using "${boheimleoni_graphs}\imputation_results.txt", text replace name(mi)
pause No need to re-do this stage to re-do the MARGINS
mi estimate, saving(miestfile, replace) esample(esample): ///
	/**/ 				reg injob i.Htert##i.country_alph##i.trend c.age#i.country_alph c.age_sq#i.country_alph i.rmale#i.country_alph ///
	/**/ 				if $age_limit  [pw=${weight}], cluster(mergeid)
	* Postestimation - gap trend (cannot be saved using ESTIMATES SAVE, hence the log file)
	mi estimate using miestfile
	mimrgns r3.Htert#r.trend@i.country_alph		using miestfile , esample(esample) 
	* Restore the model and run different margins for level trend
	mi estimate using miestfile
	mimrgns r.trend@i.country_alph		 		using miestfile , at(Htert==1) esample(esample) 
	/* OLD VERSION using LOGIT, diff MIMRGNS syntax, and trying to do MARGINSPLOT despite warnings:
		logit rworknew i.Htert##i.country2##i.trend age rmale if $age_limit [pw=${weight}], cluster(mergeid)
		mimrgns r3.Htert#r.trend@i.country_alph		using miestfile , esample(esample) predict(pr) cmdmargins
			marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) title("") xtitle("Change in health emp. gap over time") ytitle("")
			graph export "${graphDir}\MIMRGNS_BBG_gaptrendbycountry.eps", replace mag(200)	
		mimrgns r.trend@i.country_alph		 		using miestfile , at(Htert==1) esample(esample) predict(pr) cmdmargins
			marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) title("") xtitle("Change in emp among poorest health over time") ytitle("")
			graph export "${graphDir}\MIMRGNS_BBG_leveltrendbycountry.eps", replace mag(200)	
	*/
* Ending/tidying
dis "Time started is `timestarted'; time ended is: "
time
help mimrgns
dis _newline(2) in red "Beware of {mansection MI miestimatepostestimationRemarksandexamplesUsingthecommand-specificpostestimationtools:issues with MI postestimation}"	///
	_newline(1) "and {mansection MI mipredictRemarksandexamplesExample3ObtainMIestimatesofprobabilities:specifically with predicted probabilities}"						///
	_newline(1) in smcl `"For postestimation commands, see http://wlm.userweb.mwn.de/Stata/wstatmia.htm"'
pause Copy the tables above to an Excel file to compare to the results below (not possible to do formal testing)
capture log close mi

	
		
/* 
	//////////////////////////////////////
	// Compare to the non-imputed file
	//////////////////////////////////////

	// Data preparation
	*use "${hrsdir}\BoheimLeoniGeiger_${versno}_imputed_wPCA.dta", replace
	use "$inputDir\bbl_2017_analysis_v1.dta", replace
	global weight "rwtresp2"
	global age_limit "age>=50 & age<=ret_age"
	replace wave=wave_orig-1 if survey=="ELSA" & wave>=4
		label var wave "NEW VERSION OF WAVE (HRS=wave-6, ELSA turns 4-7 into 3-6)"		// BBG added
	recode wave (1/2=1 "w1-2")(5/6=2 "w5-6")(else=.), gen(trend)
		label var trend "Dummy for waves 1-2 vs. 5-6"
	recode country_waveN (70 71=70)(72 73=71)(74 75=72), copyrest gen(imputecluster)
		label copy country_waveN imputecluster, replace
		label define imputecluster 70 "70_ELSA waves 1+2" 71 "71_ELSA waves 4+5" 72 "72_ELSA waves 6+7" 73 "" 74 "" 75 "", modify
		label values imputecluster imputecluster
		label var imputecluster "Grouped survey_waveN for multiple imputation"
		order imputecluster, after(survey_waveN)

	// The models
	eststo mainmode: logit rworknew i.Htert##i.country2##i.trend age rmale if $age_limit [pw=${weight}], cluster(mergeid)
	margins r3.Htert#r.trend@i.country2 		if e(sample), predict(pr) post
	estimates restore mainmode
	margins r.trend@i.country2			 		if e(sample), at(Htert==1) predict(pr) post
*/
